This tool is an agent that performs various subtasks to collect information and execute specific actions. It can access the internet, read files, program, and process multimodal content. The subtask should be clearly defined, include relevant background, and focus on a single, well-scoped objective.
Args:
	subtask: the subtask to be performed.
Returns:
	the processed summary report of the subtask.